@@ -34,8 +34,7 @@
 #' package from `.libPaths` and delete the `DESCRIPTION` file and
 #' `SpaDES.core` will treat it as a normal module.
 #'
-#' @return
-#' This is run for its side effects. There will be a new or modified
+#' @return Invoked for its side effects. There will be a new or modified
 #' `DESCRIPTION` file in the root directory of the module. Any functions that
 #' were in the main module script (i.e., the .R file whose filename is the name of
 #' the module and is in the root directory of the module) will be moved to individual
@@ -87,15 +86,29 @@
 #' `simInit` will nevertheless run `pkgload::load_all` to ensure the
 #' `spades` call will be using the current source code.
 #'
-#' @export
 #' @param module Character string of module name, without path
-#' @param path Character string of modulePath. Defaults to
-#'   `getOption("spades.modulePath")`
+#'
+#' @param path Character string of `modulePath`. Defaults to  `getOption("spades.modulePath")`.
+#'
 #' @param buildDocuments A logical. If `TRUE`, the default, then the documentation
-#'   will be built, if any exists, using `roxygen2::roxygenise`
+#'   will be built, if any exists, using `roxygen2::roxygenise`.
+#'
+#' @return invoked for the side effect of converting a module to a package
+#'
+#' @export
+#' @examples
+#' if (requireNamespace("ggplot2") && requireNamespace("pkgload") ) {
+#'   tmpdir <- tempdir2()
+#'   newModule("test", tmpdir, open = FALSE)
+#'   convertToPackage("test", path = tmpdir)
+#'   pkgload::load_all(file.path(tmpdir, "test"))
+#'   pkgload::unload("test")
+#' }
+#'
 convertToPackage <- function(module = NULL, path = getOption("spades.modulePath"),
                              buildDocuments = TRUE) {
   mainModuleFile <- file.path(path, unlist(module), paste0(unlist(module), ".R"))
+  packageFolderName <- dirname(mainModuleFile)
   aa <- parse(mainModuleFile, keep.source = TRUE)
   rlaa <- readLines(mainModuleFile)
   gpd <- getParseData(aa)
@@ -104,57 +117,112 @@ convertToPackage <- function(module = NULL, path = getOption("spades.modulePath"
   whDefModule <- which(defModule)
   whNotDefModule <- which(!defModule)
 
-  NAMESPACEFile <- file.path(dirname(mainModuleFile), "NAMESPACE")
+  NAMESPACEFile <- filenameFromFunction(packageFolderName, "NAMESPACE", fileExt = "")
   hasNamespaceFile <- file.exists(NAMESPACEFile)
 
-  RsubFolder <- file.path(dirname(mainModuleFile), "R")
+  RsubFolder <- file.path(packageFolderName, "R")
   checkPath(RsubFolder, create = TRUE)
 
   parseWithRoxygen <- gpd[grep("#'", gpd$text), ]
   linesWithRoxygen <- parseWithRoxygen[, "line1"]
+  nextElement <- c(whNotDefModule[-1], Inf)
 
-  fileNames <- lapply(whNotDefModule, function(element) {
-    fn <- aa[[element]][[2]]
-    filePath <- file.path(dirname(mainModuleFile), "R", paste0(gsub("\\.", "", fn), ".R"))
+  fileNames <- Map(element = whNotDefModule, nextElement = nextElement,
+                   function(element, nextElement) {
+                     i <- 0
+                     fn <- filePath <- fnCh <- parseWithFn<- lineWithFn <- list()
+                     for (elem in c(element, nextElement)) {
+                       i <- i + 1
+                       if (is.infinite(elem)) {
+                         lineWithFn[[i]] <- length(rlaa) + 1
+                         break
+                       }
+                       fn[[i]] <- aa[[elem]][[2]]
+                       filePath[[i]] <- filenameFromFunction(packageFolderName, fn[[i]], "R")
+                       fnCh[[i]] <- as.character(fn[[i]])
+                       gpdLines <- which(gpd$text == fnCh[[i]] & gpd$token == "SYMBOL")
+                       if (length(gpdLines) > 1)
+                         for (gl in gpdLines) {
+                           line1 <- gpd[gl, "line1"]
+                           isTop <- any(gpd[gpd[, "line1"] == line1, "parent"] == 0)
+                           if (isTRUE(isTop)) {
+                             gpdLines <- gl
+                             break
+                           }
+                         }
+                       parseWithFn[[i]] <- gpd[gpdLines,]
+                       lineWithFn[[i]] <- parseWithFn[[i]][, "line1"]
+                       if (length(lineWithFn[[i]]) > 1) {
+                         if (i == 1) {
+                           if (length(lineWithFn[[1]]))
+                             browser()
+                           lineWithFn[[1]] <- lineWithFn[[1]][1]
+                         } else {
+                           whAfterLine1 <- which(lineWithFn[[2]] > lineWithFn[[1]])
+                           if (length(whAfterLine1))
+                             lineWithFn[[2]] <- lineWithFn[[2]][whAfterLine1[1]]
+                         }
+                       }
 
-    fnCh <- as.character(fn)
-    parseWithFn <- gpd[which(gpd$text == fnCh & gpd$token == "SYMBOL"),]
-    lineWithFn <- parseWithFn[, "line1"]
-    wh <- which((lineWithFn - linesWithRoxygen) == 1) # is the roxygen next to function
-    if (length(wh)) {
-      # This means there is a roxygen block for this function -- must keep it with the function code
-      lastRoxygenLine <- lineWithFn - 1 == linesWithRoxygen
-      ff <- diff(linesWithRoxygen)
-      ff[ff == 1] <- 0
-      ff[ff > 0] <- 1
-      ff <- cumsum(ff)
-      ff <- c(0, ff)
-      roxygenLinesForThisFn <- linesWithRoxygen[ff == ff[lastRoxygenLine]]
+                     }
+                     wh <- which((lineWithFn[[1]] - linesWithRoxygen) == 1) # is the roxygen next to function
+                     whPrev <- which((lineWithFn[[2]] - linesWithRoxygen) == 1) # is the roxygen next to function
 
-      # This removes lines if they are put into a file. That means, if there are
-      #   any left over at the end, we will put them into their own file
-      linesWithRoxygen <<- setdiff(linesWithRoxygen, roxygenLinesForThisFn)
-      cat(rlaa[roxygenLinesForThisFn], file = filePath, sep = "\n", append = FALSE)
+                     if (length(wh) || length(whPrev)) {
+                       iAll <- if(length(wh) > 0) c(1, if (length(whPrev) > 0)  2 else NULL) else 2
+                       for (i in rev(iAll)) {
+                         # This means there is a roxygen block for this function -- must keep it with the function code
+                         lastRoxygenLine <- lineWithFn[[i]] - 1 == linesWithRoxygen
+                         ff <- if (length(linesWithRoxygen) == 1) 0 else
+                           diff(linesWithRoxygen)
+                         ff[ff == 1] <- 0
+                         ff[ff > 0] <- 1
+                         ff <- cumsum(ff)
+                         ff <- c(0, ff)
 
-    }
+                         # This removes lines if they are put into a file. That means, if there are
+                         #   any left over at the end, we will put them into their own file
+                         roxygenLinesForThisFn <- linesWithRoxygen[ff == ff[lastRoxygenLine]]
+                         if (i == 1) {
+                           linesWithRoxygen <<- setdiff(linesWithRoxygen, roxygenLinesForThisFn)
+                           cat(rlaa[roxygenLinesForThisFn], file = filePath[[1]], sep = "\n", append = FALSE)
+                         } else {
+                           lineWithFn[[2]] <- min(roxygenLinesForThisFn) - 1
+                         }
+                       }
 
-    if (isTRUE(grepl("^doEvent", fn))) {
-      if (!any(grepl("@export", aa[[element]][[3]])))
-        cat("#' @export", file = filePath, sep = "\n", append = TRUE)
-    }
+                     }
+
+                     if (isTRUE(grepl("^doEvent", fn[[1]]))) {
+                       if (!any(grepl("@export", aa[[element]][[3]])))
+                         cat("#' @export", file = filePath[[1]], sep = "\n", append = TRUE)
+                     }
+
+                     cat(format(rlaa[lineWithFn[[1]]:(lineWithFn[[2]] - 1)]), file = filePath[[1]], sep = "\n", append = TRUE)
+                     # cat(format(aa[[element]]), file = filePath[[1]], sep = "\n", append = TRUE)
+                     return(filePath[[1]])
+                   })
+
+  otherStuffFn <- filenameFromFunction(packageFolderName, "other", "R")
+  cat("
+makeActiveBinding('mod', SpaDES.core:::activeModBindingFunction, ",
+      paste0('asNamespace(SpaDES.core:::.moduleNameNoUnderscore(\'',module,'\'))'),")
+
+makeActiveBinding('Par', SpaDES.core:::activeParBindingFunction, ",
+      paste0('asNamespace(SpaDES.core:::.moduleNameNoUnderscore(\'',module,'\'))'),")
+
+", file = otherStuffFn)
 
-    cat(format(aa[[element]]), file = filePath, sep = "\n", append = TRUE)
-  })
   if (length(linesWithRoxygen) > 0) {
     message("There was some roxygen2 documentation that was not immediately above ",
             "a function; it is being saved in R/documentation.R ... please confirm that ",
             "the documentation is correct.")
-    cat(rlaa[linesWithRoxygen], file = file.path(dirname(mainModuleFile), "R", "documentation.R")
-          , sep = "\n", append = FALSE)
+    cat(rlaa[linesWithRoxygen], file = filenameFromFunction(packageFolderName, "documentation", "R")
+        , sep = "\n", append = FALSE)
     linesWithRoxygen <- character()
   }
 
-  filePathImportSpadesCore <- file.path(dirname(mainModuleFile), "R", "imports.R")
+  filePathImportSpadesCore <- filenameFromFunction(packageFolderName, "imports", "R")# file.path(dirname(mainModuleFile), "R", "imports.R")
 
   cat(format(aa[[whDefModule]]), file = mainModuleFile, sep = "\n")
   md <- aa[[whDefModule]][[3]]
@@ -197,13 +265,13 @@ convertToPackage <- function(module = NULL, path = getOption("spades.modulePath"
 
   d$Imports[hasVersionNumb] <- paste(d$Imports[hasVersionNumb], inequality)
 
-  dFile <- file.path(dirname(mainModuleFile), "DESCRIPTION")
+  dFile <- filenameFromFunction(packageFolderName, "DESCRIPTION", fileExt = "")
 
   cat(paste("Package:", d$Package), file = dFile, sep = "\n")
   cat(paste("Type:", d$Type), file = dFile, sep = "\n", append = TRUE)
   cat(paste("Title:", d$Title), file = dFile, sep = "\n", append = TRUE)
   cat(paste("Version:", d$Version), file = dFile, sep = "\n", append = TRUE)
-  cat(paste("Description:", d$Description), file = dFile, sep = "\n", append = TRUE)
+  cat(paste("Description:", paste(d$Description, collapse = " ")), file = dFile, sep = "\n", append = TRUE)
   cat(paste("Date:", d$Date), file = dFile, sep = "\n", append = TRUE)
   cat(c("Authors@R:  ", format(d$Authors)), file = dFile, sep = "\n", append = TRUE)
 
@@ -224,13 +292,13 @@ convertToPackage <- function(module = NULL, path = getOption("spades.modulePath"
 
   if (isTRUE(buildDocuments)) {
     message("Building documentation")
-    m <- dirname(mainModuleFile)
+    m <- packageFolderName
     roxygen2::roxygenise(m, roclets = NULL) # This builds documentation, but also exports all functions ...
     pkgload::dev_topic_index_reset(m)
     pkgload::unload(.moduleNameNoUnderscore(basename2(m))) # so, unload here before reloading without exporting
   }
 
-  RBuildIgnoreFile <- file.path(dirname(mainModuleFile), ".Rbuildignore")
+  RBuildIgnoreFile <- filenameFromFunction(packageFolderName, ".Rbuildignore", fileExt = "")
   cat("^.*\\.Rproj$
 ^\\.Rproj\\.user$
 ^_pkgdown\\.yml$
@@ -256,8 +324,10 @@ vignettes/.*\\.log$
     ", sep = "\n",
       file = RBuildIgnoreFile, fill = TRUE)
 
-
-
   return(invisible())
 
 }
+
+filenameFromFunction <- function(packageFolderName, fn = "", subFolder = "", fileExt = ".R") {
+  normPath(file.path(packageFolderName, subFolder, paste0(gsub("\\.", "", fn), fileExt)))
+}
