@@ -1,11 +1,7 @@
 test_that("test checkpointing", {
   skip_on_cran()
-  skip_if_not_installed("NLMR")
 
-  testInitOut <- testInit(smcc = FALSE, opts = list(spades.recoveryMode = FALSE))
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+  testInit(sampleModReqdPkgs, opts = list(spades.recoveryMode = FALSE))
 
   file <- file.path("chkpnt.qs")
   ## save checkpoints; no load/restore
@@ -19,7 +15,7 @@ test_that("test checkpointing", {
   )
   modules <- list("randomLandscapes", "caribouMovement")
   paths <- list(
-    modulePath = system.file("sampleModules", package = "SpaDES.core"),
+    modulePath = getSampleModules(tmpdir),
     outputPath = tmpdir
   )
   simA <- simInit(times = times, params = parameters, modules = modules, paths = paths)
@@ -39,21 +35,18 @@ test_that("test checkpointing", {
 
   rm("._startClockTime", envir = envir(simB))
   rm("._startClockTime", envir = envir(simA))
-  rm("._timestamp", envir = envir(simB))
-  rm("._timestamp", envir = envir(simA))
+  # rm("._timestamp", envir = envir(simB))
+  # rm("._timestamp", envir = envir(simA))
 
   ## both versions above should yield identical results
-  expect_equal(simA, simB)
+  expect_equivalent(simA, simB)
 })
 
 test_that("test checkpointing with disk-backed raster", {
   skip_on_cran()
-  skip_if_not_installed("NLMR")
 
-  testInitOut <- testInit(smcc = FALSE, opts = list(spades.recoveryMode = FALSE))
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+  testInit(sampleModReqdPkgs,
+                          opts = list(spades.recoveryMode = FALSE))
 
   file <- file.path("chkpnt.qs")
 
@@ -68,11 +61,11 @@ test_that("test checkpointing with disk-backed raster", {
   )
   modules <- list("randomLandscapes", "caribouMovement")
   paths <- list(
-    modulePath = system.file("sampleModules", package = "SpaDES.core"),
+    modulePath = getSampleModules(tmpdir),
     outputPath = tmpdir
   )
   simA <- simInit(times = times, params = parameters, modules = modules, paths = paths)
-  simA$ras <- raster(extent(0, 10, 0, 10), vals = 1)
+  simA$ras <- terra::rast(terra::ext(0, 10, 0, 10), vals = 1)
   tmpRasFilename <- tempfile("tmpRas", fileext = ".grd") %T>%
     file.create() %>%
     normPath()
@@ -83,14 +76,14 @@ test_that("test checkpointing with disk-backed raster", {
   ## save checkpoints; with load/restore
   set.seed(1234)
   simB <- simInit(times = times, params = parameters, modules = modules, paths = paths)
-  simB$ras <- raster(extent(0,10,0,10), vals = 1)
+  simB$ras <- terra::rast(terra::ext(0,10,0,10), vals = 1)
   expect_error(simB$ras <- writeRaster(simA$ras, filename = tmpRasFilename))
 
   # Eliot uncommented this next line Sept 17, 2019 b/c writeRaster next line newly failed
   # filenames of source and target should be different
   tmpRasFilename <- tempfile("tmpRas", fileext = ".grd")
   if (file.exists(tmpRasFilename)) unlink(tmpRasFilename)
-  simA$ras[] <- getValues(simA$ras)
+  simA$ras[] <- simA$ras[]
   simB$ras <- writeRaster(simA$ras, filename = tmpRasFilename)
   end(simB) <- 1
   simB <- spades(simB)
