@@ -1,17 +1,14 @@
 test_that("downloadModule downloads and unzips a single module", {
   skip_on_cran()
-  skip_if_not_installed("httr")
 
-  if (Sys.info()["sysname"] == "Windows") {
-    options(download.file.method = "auto")
+  opts <- list(reproducible.inputPaths = NULL)
+  if (isWindows()) {
+    opts <- append(opts, list(download.file.method = "auto"))
   } else {
-    options(download.file.method = "curl", download.file.extra = "-L")
+    opts <- append(opts, list(download.file.method = "curl", download.file.extra = "-L"))
   }
 
-  testInitOut <- testInit("raster", smcc = FALSE)
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+  testInit(opts = opts, "httr")
 
   m <- "test"
 
@@ -34,23 +31,18 @@ test_that("downloadModule downloads and unzips a single module", {
 
 test_that("downloadModule downloads and unzips a parent module", {
   skip_on_cran()
-  skip_if_not_installed("httr")
-
-  if (Sys.info()["sysname"] == "Windows") {
-    options(download.file.method = "auto")
-  } else {
-    options(download.file.method = "curl")
-  }
-
-  testInitOut <- testInit("raster", smcc = FALSE)
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
 
+  testInit(c("terra", "httr"), smcc = FALSE)
   m <- "LCC2005"
 
   ## f <- downloadModule(m, tmpdir, quiet = TRUE)[[1]] %>% unlist() %>% as.character()
   f <- .tryCatch(downloadModule(m, tmpdir, quiet = TRUE, data = FALSE))
+  dirTD <- dir(tmpdir, recursive = TRUE)
+  gotAllMods <- all(unlist(Map(yy = c("caribouMovementLcc", "cropReprojectLccAge", "fireSpreadLcc",
+           "forestAge", "forestSuccessionBeacons", "LCC2005", "LccToBeaconsReclassify"),
+         function(yy) any(grepl(yy, x = dirTD)))))
+  if (!isTRUE(gotAllMods)) skip("Download didn't work correctly; likely no GITHUB_PAT")
+  if (length(dirTD) < 16) skip("Download didn't work correctly; likely no GITHUB_PAT")
   if (!is.null(f$error)) {
     if (grepl("Forbidden", f$error)) {
       skip("Forbidden HTTP 403 on GitHub during downloadModule")
@@ -70,13 +62,13 @@ test_that("downloadModule downloads and unzips a parent module", {
 
 test_that("downloadModule can overwrite existing modules", {
   skip_on_cran()
-  skip_if_not_installed("httr")
-
-  if (Sys.info()["sysname"] == "Windows") {
-    options(download.file.method = "auto")
+  opts <- list(reproducible.inputPaths = NULL)
+  if (isWindows()) {
+    opts <- append(opts, list(download.file.method = "auto"))
   } else {
-    options(download.file.method = "curl", download.file.extra = "-L")
+    opts <- append(opts, list(download.file.method = "curl", download.file.extra = "-L"))
   }
+  testInit("httr")
 
   m <- "LccToBeaconsReclassify"
   tmpdir <- file.path(tempdir(), "modules") %>% checkPath(create = TRUE)
@@ -112,33 +104,34 @@ test_that("downloadModule can overwrite existing modules", {
 
 test_that("downloadModule does not fail when data URLs cannot be accessed", {
   skip_on_cran()
-  skip_if_not_installed("httr")
 
-  if (identical(Sys.getenv("TRAVIS"), "true") &&
-      tolower(Sys.info()[["sysname"]]) == "darwin") skip("On Travis OSX")
-
-  if (Sys.info()["sysname"] == "Windows") {
-    options(download.file.method = "auto")
+  opts <- list(reproducible.inputPaths = NULL, "reproducible.verbose" = TRUE)
+  if (isWindows()) {
+    opts <- append(opts, list(download.file.method = "auto"))
   } else {
-    options(download.file.method = "curl", download.file.extra = "-L")
+    opts <- append(opts, list(download.file.method = "curl", download.file.extra = "-L"))
   }
 
+  testInit(c("httr", "dplyr"), opts = opts)
   m <- "test"
-  tmpdir <- file.path(tempdir(), "modules") %>% checkPath(create = TRUE)
-  on.exit(unlink(tmpdir, recursive = TRUE), add = TRUE)
 
-  if (paste0(R.version$major, ".", R.version$minor) > "3.4.2") {
-    f <- .tryCatch(downloadModule(m, tmpdir, quiet = TRUE, data = TRUE))
-    if (!is.null(f$error)) {
-      if (grepl("Forbidden", f$error)) {
-        skip("Forbidden HTTP 403 on GitHub during downloadModule")
-      }
+  skipMessReGoogledrive <-
+    "Need a newer version of reproducible for downloadData for non-googledrive urls"
+  if (packageVersion("reproducible") <= "1.2.16")
+    skip(skipMessReGoogledrive)
+  f <- .tryCatch(downloadModule(m, tmpdir, quiet = TRUE, data = TRUE))
+  if (!is.null(f$error)) {
+    if (grepl("Forbidden", f$error)) {
+      skip("Forbidden HTTP 403 on GitHub during downloadModule")
+    }
+    if (grepl("no package called", f$error)) {
+      skip(skipMessReGoogledrive)
     }
-    f <- f$value[[1]] %>% unlist() %>% as.character()
-    d <- f %>% dirname() %>% basename() %>% unique() %>% sort()
-
-    d_expected <- sort(c(m, "data"))
-
-    expect_equal(d, d_expected)
   }
+  f <- f$value[[1]] %>% unlist() %>% as.character()
+  d <- f %>% dirname() %>% basename() %>% unique() %>% sort()
+
+  d_expected <- sort(c(m, "data"))
+
+  expect_equal(d, d_expected)
 })
