@@ -1,81 +1,78 @@
-test_that("test-load.R: loading inputs does not work correctly", {
-  skip_if_not_installed("NLMR")
+test_that("loading inputs does not work correctly", {
+  testInit(c(sampleModReqdPkgs, "quickPlot"))
 
-  testInitOut <- testInit()
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+  mapPath <- getMapPath(tmpdir)
 
-  mapPath <- system.file("maps", package = "quickPlot")
+  functions <- c("raster", "rast")
+  packages <- c("raster", "terra")
+  for (i in seq(functions)) {
+    filelist <- data.frame(
+      files = dir(file.path(mapPath), full.names = TRUE, pattern = "tif")[1:2],
+      functions = functions[i],
+      package = packages[i],
+      stringsAsFactors = FALSE
+    )
 
-  filelist <- data.frame(
-    files = dir(file.path(mapPath), full.names = TRUE, pattern = "tif")[1:2],
-    functions = "raster",
-    package = "raster",
-    stringsAsFactors = FALSE
-  )
+    times <- list(start = 0, end = 1)
+    parameters <- list(
+      .globals = list(stackName = "landscape"),
+      caribouMovement = list(.plotInitialTime = NA),
+      randomLandscapes = list(.plotInitialTime = NA, nx = 20, ny = 20)
+    )
+    modules <- list("randomLandscapes", "caribouMovement")
+    paths <- list(
+      modulePath = getSampleModules(tmpdir),
+      inputPath = mapPath,
+      outputPath = tmpdir
+    )
 
-  times <- list(start = 0, end = 1)
-  parameters <- list(
-    .globals = list(stackName = "landscape"),
-    caribouMovement = list(.plotInitialTime = NA),
-    randomLandscapes = list(.plotInitialTime = NA, nx = 20, ny = 20)
-  )
-  modules <- list("randomLandscapes", "caribouMovement")
-  paths <- list(
-    modulePath = system.file("sampleModules", package = "SpaDES.core"),
-    inputPath = mapPath,
-    outputPath = tmpdir
-  )
+    mySim <- simInit(times = times, params = parameters, modules = modules, paths = paths)
+    mySim <- spades(mySim)
+    expect_true(all(c("DEM", "forestAge") %in% names(mySim$landscape)))
 
-  mySim <- simInit(times = times, params = parameters, modules = modules, paths = paths)
-  mySim <- spades(mySim)
-  expect_true(all(c("DEM", "forestAge") %in% names(mySim$landscape)))
+    # test overall inputs setReplaceMethod
+    inputs  <- data.frame(
+      files = dir(file.path(mapPath), full.names = TRUE, pattern = "tif")[1:2],
+      functions = functions[i],
+      package = packages[i],
+      loadTime = c(0, 3),
+      stringsAsFactors = FALSE
+    )
+    inputs(mySim) <- inputs
+    expect_equal(inputs(mySim)[, c("file", "fun", "package", "loadTime")], inputs)
+    expect_equal(fileName(inputs(mySim)$file), inputs(mySim)$objectName)
+    expect_equal(inputs(mySim)$loaded, rep(NA, NROW(inputs(mySim))))
 
-  # test overall inputs setReplaceMethod
-  inputs  <- data.frame(
-    files = dir(file.path(mapPath), full.names = TRUE, pattern = "tif")[1:2],
-    functions = "raster",
-    package = "raster",
-    loadTime = c(0, 3),
-    stringsAsFactors = FALSE
-  )
-  inputs(mySim) <- inputs
-  expect_equal(inputs(mySim)[, c("file", "fun", "package", "loadTime")], inputs)
-  expect_equal(fileName(inputs(mySim)$file), inputs(mySim)$objectName)
-  expect_equal(inputs(mySim)$loaded, rep(NA, NROW(inputs(mySim))))
+    # test fill in objectName and function and package
+    inputs  <- data.frame(
+      files = dir(file.path(mapPath), full.names = TRUE, pattern = "tif")[1:2],
+      loadTime = c(0, 3),
+      stringsAsFactors = FALSE
+    )
+    inputs(mySim) <- inputs
+    expect_equal(inputs(mySim)[, c("file", "loadTime")], inputs)
+    expect_equal(fileName(inputs(mySim)$file), inputs(mySim)$objectName)
+    expect_equal(inputs(mySim)$loaded, rep(NA, NROW(inputs(mySim))))
 
-  # test fill in objectName and function and package
-  inputs  <- data.frame(
-    files = dir(file.path(mapPath), full.names = TRUE, pattern = "tif")[1:2],
-    loadTime = c(0, 3),
-    stringsAsFactors = FALSE
-  )
-  inputs(mySim) <- inputs
-  expect_equal(inputs(mySim)[, c("file", "loadTime")], inputs)
-  expect_equal(fileName(inputs(mySim)$file), inputs(mySim)$objectName)
-  expect_equal(inputs(mySim)$loaded, rep(NA, NROW(inputs(mySim))))
+    # test override default object name
+    inputs  <- data.frame(
+      files = dir(file.path(mapPath), full.names = TRUE, pattern = "tif")[1:2],
+      objectName = c("rasDEM", "rasForestAge"),
+      stringsAsFactors = FALSE
+    )
+    inputs(mySim) <- inputs
+    expect_equal(inputs(mySim)[, c("file", "objectName")], inputs)
+    expect_equal(inputs(mySim)$objectName, inputs$objectName)
+    expect_equal(inputs(mySim)$loaded, rep(NA, NROW(inputs(mySim))))
 
-  # test override default object name
-  inputs  <- data.frame(
-    files = dir(file.path(mapPath), full.names = TRUE, pattern = "tif")[1:2],
-    objectName = c("rasDEM", "rasForestAge"),
-    stringsAsFactors = FALSE
-  )
-  inputs(mySim) <- inputs
-  expect_equal(inputs(mySim)[, c("file", "objectName")], inputs)
-  expect_equal(inputs(mySim)$objectName, inputs$objectName)
-  expect_equal(inputs(mySim)$loaded, rep(NA, NROW(inputs(mySim))))
-
-  rm(mySim)
+    rm(mySim)
+  }
 
   # use loadFiles directly
-  if (require(rgdal, quietly = TRUE)) {
-    on.exit(detach("package:rgdal"), add = TRUE)
     sim1 <- loadFiles(
       filelist = filelist,
       paths = list(
-        modulePath = system.file("sampleModules", package = "SpaDES.core"),
+        modulePath = getSampleModules(tmpdir),
         inputPath = mapPath,
         outputPath = file.path(tmpdir, rndstr()))
     )
@@ -83,48 +80,47 @@ test_that("test-load.R: loading inputs does not work correctly", {
     rm(sim1)
 
     # load at future time, i.e., nothing gets loaded
-    inputs <- data.frame(
-      files = dir(file.path(mapPath), full.names = TRUE, pattern = "tif")[1:2],
-      functions = "raster",
-      package = "raster",
-      loadTime = 3,
-      stringsAsFactors = FALSE
-    )
-    mySim <- simInit(times = times, params = parameters, modules = modules,
-                     paths = paths, inputs = inputs)
-    expect_true(!any(c("DEM", "forestAge") %in% ls(mySim)))
-    rm(mySim)
+    for (i in seq(packages)) {
+      inputs <- data.frame(
+        files = dir(file.path(mapPath), full.names = TRUE, pattern = "tif")[1:2],
+        functions = functions[i],
+        package = packages[i],
+        loadTime = 3,
+        stringsAsFactors = FALSE
+      )
+      mySim <- simInit(times = times, params = parameters, modules = modules,
+                       paths = paths, inputs = inputs)
+      expect_true(!any(c("DEM", "forestAge") %in% ls(mySim)))
+      rm(mySim)
 
-    # load some at future time, i.e., only one gets loaded
-    inputs <- data.frame(
-      files = dir(file.path(mapPath), full.names = TRUE, pattern = "tif")[1:2],
-      functions = "raster",
-      package = "raster",
-      loadTime = c(0, 3),
-      stringsAsFactors = FALSE
-    )
-    mySim <- simInit(times = times, params = parameters, modules = modules,
-                     paths = paths, inputs = inputs)
+      # load some at future time, i.e., only one gets loaded
+      inputs <- data.frame(
+        files = dir(file.path(mapPath), full.names = TRUE, pattern = "tif")[1:2],
+        functions = functions[i],
+        package = packages[i],
+        loadTime = c(0, 3),
+        stringsAsFactors = FALSE
+      )
+      mySim <- simInit(times = times, params = parameters, modules = modules,
+                       paths = paths, inputs = inputs)
 
-    expect_true(c("DEM") %in% ls(mySim))
-    expect_true(!any(c("forestAge") %in% ls(mySim)))
-    rm(mySim)
-  }
+      expect_true(c("DEM") %in% ls(mySim))
+      expect_true(!any(c("forestAge") %in% ls(mySim)))
+      rm(mySim)
+    }
+  # }
 })
 
-test_that("test-load.R: passing arguments to filelist in simInit does not work correctly", {
-  skip_if_not_installed("NLMR")
+test_that("passing arguments to filelist in simInit does not work correctly", {
+  skip_on_cran()
 
-  testInitOut <- testInit()
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+  testInit(c(sampleModReqdPkgs, "quickPlot", "data.table"))
 
   # Second, more sophisticated. All maps loaded at time = 0, and the last one is reloaded
   #  at time = 10 and 20 (via "intervals").
   # Also, pass the single argument as a list to all functions...
   #  specifically, when add "native = TRUE" as an argument to the raster function
-  mapPath <- system.file("maps", package = "quickPlot")
+  mapPath <- getMapPath(tmpdir)
   files <- dir(file.path(mapPath), full.names = TRUE, pattern =  "tif")[1:4]
   parameters <- list(
     .globals = list(stackName = "landscape"),
@@ -133,35 +129,39 @@ test_that("test-load.R: passing arguments to filelist in simInit does not work c
   )
   modules <- list("randomLandscapes", "caribouMovement")
   paths <- list(
-    modulePath = system.file("sampleModules", package = "SpaDES.core"),
+    modulePath = getSampleModules(tmpdir),
     inputPath = mapPath,
     outputPath = tmpdir
   )
 
-  inputs <- data.frame(
-    files = files,
-    functions = rep("raster::raster", 4),
-    objectName = rep(NA, 4),
-    loadTime = c(0, 1, 1, 3),
-    intervals = c(NA, 1, 2, NA),
-    args = I(rep(list("native" = TRUE), 4)),
-    stringsAsFactors = FALSE
-  )
-  times <- list(start = 0, end = 1, timeunit = "seconds")
+  fns <- c("raster::raster", "terra::rast")
+  args <- list(I(rep(list("native" = TRUE), 4)), NULL)
+  for (i in seq(fns)) {
+    inputs <- data.frame(
+      files = files,
+      functions = rep(fns[i], 4),
+      objectName = rep(NA, 4),
+      loadTime = c(0, 1, 1, 3),
+      intervals = c(NA, 1, 2, NA),
+      stringsAsFactors = FALSE
+    )
+    if (length(args[[i]]))
+      inputs$args = args[[i]]
+
+    times <- list(start = 0, end = 1, timeunit = "seconds")
 
-  if (require(rgdal, quietly = TRUE)) {
-    on.exit(detach("package:rgdal"), add = TRUE)
     sim2 <- simInit(times = times, params = parameters, modules = modules,
                     paths = paths, inputs = inputs)
     expect_true(c("DEM") %in% ls(sim2))
 
     # Test that arguments got passed in correctly
-    expect_equal(inputs(sim2)$arguments, I(rep(list(native = TRUE), 4)))
+    if (length(args[[i]]))
+      expect_equal(inputs(sim2)$arguments, I(rep(list(native = TRUE), 4)))
     expect_true(!any(c("forestCover", "forestAge", "habitatQuality") %in% ls(sim2)))
 
     sim2 <- spades(sim2)
     expect_true(all(c("DEM", "forestAge", "forestCover") %in% ls(sim2)))
-    expect_true(!any(c("habitatQuality") %in% ls(sim2)))
+    expect_true(!any(c("percentPine") %in% ls(sim2)))
 
     rm(forestAge, envir = envir(sim2))
     expect_true(!("forestAge" %in% ls(sim2)))
@@ -176,52 +176,52 @@ test_that("test-load.R: passing arguments to filelist in simInit does not work c
     expect_message(spades(sim2), "forestAge")
     expect_true(all(c("DEM", "forestAge", "forestCover") %in% ls(sim2)))
     rm(sim2)
-
-    # test without package specified
-    dt <- data.table::data.table(a = 3, b = 2)
-    tmpFile <- tempfile()
-    write.table(dt, file = tmpFile, sep = "\t", col.names = TRUE, row.names = FALSE)
-    inputs <- data.frame(
-      files = tmpFile,
-      functions = "data.table::fread",
-      stringsAsFactors = FALSE
-    )
-    sim2 <- simInit(times = times, params = parameters, modules = modules,
-                    paths = paths, inputs = inputs)
-    expect_equal(sim2@.xData[[basename(tmpFile)]], dt)
-
-    inputs <- data.frame(
-      files = tmpFile,
-      functions = "fread",
-      stringsAsFactors = FALSE
-    )
-    require(data.table)
-    mess <- capture_messages(simInit(times = times, params = parameters, modules = modules,
-                                     paths = paths, inputs = inputs))
-    expect_true(any(grepl(paste(basename(tmpFile)), mess)))
   }
+  # test without package specified
+  dt <- data.table::data.table(a = 3, b = 2)
+  tmpFile <- tempfile()
+  write.table(dt, file = tmpFile, sep = "\t", col.names = TRUE, row.names = FALSE)
+  inputs <- data.frame(
+    files = tmpFile,
+    functions = "data.table::fread",
+    stringsAsFactors = FALSE
+  )
+  sim2 <- simInit(times = times, params = parameters, modules = modules,
+                  paths = paths, inputs = inputs)
+  expect_equal(sim2@.xData[[basename(tmpFile)]], dt)
+
+  inputs <- data.frame(
+    files = tmpFile,
+    functions = "fread",
+    stringsAsFactors = FALSE
+  )
+  mess <- capture_messages(simInit(times = times, params = parameters, modules = modules,
+                                   paths = paths, inputs = inputs))
+  expect_true(any(grepl(paste(basename(tmpFile)), mess)))
+  # }
 })
 
-test_that("test-load.R: passing objects to simInit does not work correctly", {
-  skip_if_not_installed("NLMR")
+test_that("passing objects to simInit does not work correctly", {
+  testInit(c(sampleModReqdPkgs, "quickPlot"))
 
-  testInitOut <- testInit()
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
-
-  mapPath <- mapPath <- system.file("maps", package = "quickPlot")
+  mapPath <- mapPath <- getMapPath(tmpdir)
 
   # test object passing directly
-  if (require(rgdal, quietly = TRUE)) {
-    on.exit(detach("package:rgdal"), add = TRUE)
+  functions <- c("raster", "rast")
+  packages <- c("raster", "terra")
+  if (!requireNamespace("raster", quietly = TRUE)) {
+    functions <- functions[2]
+    packages <- packages[2]
+  }
+
+  for (i in seq(functions)) {
     filelist <- data.frame(
       files = dir(file.path(mapPath), full.names = TRUE, pattern = "tif")[1:2],
-      functions = "raster",
-      package = "raster",
+      functions = functions[i],
+      package = packages[i],
       stringsAsFactors = FALSE
     )
-    layers <- lapply(filelist$files, raster)
+    layers <- lapply(filelist$files, getFromNamespace(functions[i], ns = packages[i]))
     DEM <- layers[[1]]
     forestAge <- layers[[2]]
 
@@ -233,7 +233,7 @@ test_that("test-load.R: passing objects to simInit does not work correctly", {
     )
     modules <- list("randomLandscapes", "caribouMovement")
     paths <- list(
-      modulePath = system.file("sampleModules", package = "SpaDES.core"),
+      modulePath = getSampleModules(tmpdir),
       inputPath = mapPath,
       outputPath = tmpdir
     )
@@ -263,8 +263,8 @@ test_that("test-load.R: passing objects to simInit does not work correctly", {
     # test object passing directly
     filelist <- data.frame(
       files = dir(file.path(mapPath), full.names = TRUE, pattern = "tif")[2],
-      functions = "raster",
-      package = "raster",
+      functions = functions[i],
+      package = packages[i],
       loadTime = 1,
       stringsAsFactors = FALSE
     )
@@ -279,24 +279,31 @@ test_that("test-load.R: passing objects to simInit does not work correctly", {
   }
 })
 
-test_that("test-load.R: passing nearly empty file to simInit does not work correctly", {
-  testInitOut <- testInit()
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+test_that("passing nearly empty file to simInit does not work correctly", {
+  testInit(c("terra", "quickPlot"))
 
-  mapPath <- system.file("maps", package = "quickPlot")
+  mapPath <- mapPath <- getMapPath(tmpdir)
 
   # test object passing directly
-  if (require(rgdal, quietly = TRUE)) {
-    on.exit(detach("package:rgdal"), add = TRUE)
+  functions <- c("raster", "rast")
+  packages <- c("raster", "terra")
+  if (!requireNamespace("raster", quietly = TRUE)) {
+    functions <- functions[2]
+    packages <- packages[2]
+  }
+
+  for (i in seq(functions)) {
+
+    mapPath <- getMapPath(tmpdir)
+
+    # test object passing directly
     filelist <- data.frame(
       files = dir(file.path(mapPath), full.names = TRUE, pattern = "tif")[1:2],
-      functions = "raster",
-      package = "raster",
+      functions = functions[i],
+      package = packages[i],
       stringsAsFactors = FALSE
     )
-    layers <- lapply(filelist$files, raster)
+    layers <- lapply(filelist$files, getFromNamespace(functions[i], ns = packages[i]))
     DEM <- layers[[1]]
     forestAge <- layers[[2]]
 
@@ -309,13 +316,10 @@ test_that("test-load.R: passing nearly empty file to simInit does not work corre
   }
 })
 
-test_that("test-load.R: more tests", {
+test_that("more tests", {
   skip_on_cran()
 
-  testInitOut <- testInit()
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+  testInit("raster")
 
   sim <- simInit()
   test <- 1:10
@@ -332,11 +336,8 @@ test_that("test-load.R: more tests", {
   expect_identical(bb$test, test)
 
   # Test for incremental loading via intervals
-  if (require(rgdal, quietly = TRUE)) {
-    on.exit(detach("package:rgdal"), add = TRUE)
 
-    files <- dir(system.file("maps", package = "quickPlot"),
-                full.names = TRUE, pattern = "tif")
+    files <- dir(getMapPath(tmpdir), full.names = TRUE)
     arguments <- I(rep(list(native = TRUE), length(files)))
     filelist <- data.frame(
        files = files,
@@ -359,14 +360,11 @@ test_that("test-load.R: more tests", {
     expect_message({
       sim3 <- spades(sim2)
     }, "time 20")
-  }
+  # }
 })
 
-test_that("test-load.R: interval loading of objects from .GlobalEnv", {
-  testInitOut <- testInit()
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+test_that("interval loading of objects from .GlobalEnv", {
+  testInit("ggplot2")
 
   times <- 0:10
   test1 <- "hi"
@@ -415,31 +413,46 @@ test_that("test-load.R: interval loading of objects from .GlobalEnv", {
 })
 
 test_that("Filenames for simList", {
-  testInitOut <- testInit(c("raster"), tmpFileExt = c(".tif", ".grd", ".tif", ".tif", ".grd"),
+  testInit(c("terra"), tmpFileExt = c(".tif", ".grd", ".tif", ".tif", ".grd"),
                           opts = list("reproducible.ask" = FALSE))
 
-  on.exit({
-    testOnExit(testInitOut)
-    options(opts)
-    rm(s)
-  }, add = TRUE)
+  mapPath <- getMapPath(tmpdir)
 
   s <- simInit()
-  s$r <- raster(extent(0, 10, 0, 10), vals = 1, res = 1)
-  s$r2 <- raster(extent(0, 10, 0, 10), vals = 1, res = 1)
-  s$r <- suppressWarnings(writeRaster(s$r, filename = tmpfile[1], overwrite = TRUE))
-  s$r2 <- suppressWarnings(writeRaster(s$r2, filename = tmpfile[3], overwrite = TRUE))
-  s$s <- stack(s$r, s$r2)
-  a <- s$s
-  a[] <- a[]
-  s$b <- writeRaster(a, filename = tmpfile[5], overwrite = TRUE)
+  packages <- c("raster", "terra")
+  functions <- cbind(c("raster", "extent", "stack", "nlayers"),
+                     c("rast", "ext", "rast", "nlyr"))
+  if (!requireNamespace("raster", quietly = TRUE)) {
+    functions <- functions[, 2,drop = FALSE]
+    packages <- packages[2]
+  }
+  for (i in seq(packages)) {
+    read <- getFromNamespace(functions[1, i], ns = packages[i])
+    ext <- getFromNamespace(functions[2, i], ns = packages[i])
+    if (packages[i] %in% "raster")
+      stk <- getFromNamespace(functions[3, i], ns = packages[i])
+    else
+      stk <- c
+    nlyr <- getFromNamespace(functions[4, i], ns = packages[i])
 
-  Fns <- Filenames(s)
+    s$r <- read(ext(0, 10, 0, 10), vals = 1, res = 1)
+    s$r2 <- read(ext(0, 10, 0, 10), vals = 1, res = 1)
+    s$r <- suppressWarnings(writeRaster(s$r, filename = tmpfile[1], overwrite = TRUE))
+    s$r2 <- suppressWarnings(writeRaster(s$r2, filename = tmpfile[3], overwrite = TRUE))
+    s$s <- stk(s$r, s$r2)
+    a <- s$s
+    a[] <- a[]
+    a <- stk(a)
+    s$b <- writeRaster(a, filename = tmpfile[5], overwrite = TRUE)
+    s$b <- stk(s$b)
+    Fns <- Filenames(s)
 
-  fnsGrd <- normPath(c(filename(s$b), gsub("grd$", "gri", filename(s$b))))
-  expect_true(identical(c(Fns[["b1"]], Fns[["b2"]]), fnsGrd))
-  expect_true(identical(Fns[["r"]], normPath(filename(s$r))))
-  expect_true(identical(Fns[["r2"]], normPath(filename(s$r2))))
-  expect_true(identical(c(Fns[["s1"]], Fns[["s2"]]),
-              sapply(seq_len(nlayers(s$s)), function(rInd) normPath(filename(s$s[[rInd]])))))
+    fnsGrd <- normPath(c(Filenames(s$b)))#, gsub("grd$", "gri", Filenames(s$b))))
+    expect_true(identical(c(Fns[["b1"]], Fns[["b2"]]), fnsGrd))
+    expect_true(identical(Fns[["r"]], normPath(Filenames(s$r))))
+    expect_true(identical(Fns[["r2"]], normPath(Filenames(s$r2))))
+    expect_true(identical(c(Fns[["s1"]], Fns[["s2"]]),
+                          sapply(seq_len(nlyr(s$s)), function(rInd)
+                            normPath(Filenames(s$s[[rInd]])))))
+  }
 })
